.. _api:

API Reference
=============

This page contains detailed API documentation for all public classes and functions in hpiPy.

.. toctree::
   :maxdepth: 2
   :caption: API Modules

   price_index
   price_model
   transaction_data
   period_table
   time_matrix
   metrics
   datasets
